@@ -13,29 +13,6 @@ pub fn is_well_formed_non_zero(values: &[usize]) -> bool {
     values.last().map_or(false, |&last| last != 0)
 }
 
-#[must_use]
-#[inline]
-pub fn widening_mul(left: usize, right: usize) -> (usize, usize) {
-    #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
-    fn inner(left: usize, right: usize) -> (usize, usize) {
-        let mut high_out;
-        let mut low_out;
-
-        unsafe {
-            asm!(
-            "mul {v}",
-            v = in(reg) right,
-            inout("rax") left => low_out,
-            out("rdx") high_out,
-            );
-        }
-
-        (high_out, low_out)
-    }
-
-    inner(left, right)
-}
-
 #[must_use]
 #[inline]
 pub fn add_2(left_high: usize, left_low: usize, right_high: usize, right_low: usize) -> (usize, usize) {
@@ -151,7 +128,7 @@ pub fn to_twos_complement<const S: usize>(values: &mut SmallVec<[usize; S]>) {
     let mut carry = true;
 
     for value in values.iter_mut() {
-        carry = carrying_sub_mut(value, 0, carry);
+        borrowing_sub_mut(value, 0, &mut carry);
         *value = !*value;
     }
 
@@ -171,7 +148,7 @@ pub unsafe fn add_assign_slice(values: &mut [usize], rhs: &[usize]) -> bool {
 
     let mut carry = false;
     for (value, rhs_value) in values.iter_mut().zip(rhs.iter()) {
-        carry = carrying_add_mut(value, *rhs_value, carry);
+        carrying_add_mut(value, *rhs_value, &mut carry);
     }
 
     carry
@@ -183,49 +160,31 @@ pub unsafe fn sub_assign_slice(values: &mut [usize], rhs: &[usize]) -> bool {
 
     let mut carry = false;
     for (value, rhs_value) in values.iter_mut().zip(rhs.iter()) {
-        carry = carrying_sub_mut(value, *rhs_value, carry);
+        borrowing_sub_mut(value, *rhs_value, &mut carry);
     }
 
     carry
 }
 
 #[inline]
-pub fn carrying_add_mut(value: &mut usize, rhs: usize, carry: bool) -> bool {
-    let (new_value, new_carry) = carrying_add(*value, rhs, carry);
+pub fn carrying_add_mut(value: &mut usize, rhs: usize, carry: &mut bool) {
+    let (new_value, new_carry) = value.carrying_add(rhs, *carry);
     *value = new_value;
-    new_carry
-}
-
-// Copied from an open pr on rust
-#[must_use]
-#[inline]
-pub fn carrying_add(value: usize, rhs: usize, carry: bool) -> (usize, bool) {
-    let (a, b) = value.overflowing_add(rhs);
-    let (c, d) = a.overflowing_add(carry as usize);
-    (c, b | d)
+    *carry = new_carry;
 }
 
 #[inline]
-pub fn carrying_sub_mut(value: &mut usize, rhs: usize, carry: bool) -> bool {
-    let (new_value, new_carry) = carrying_sub(*value, rhs, carry);
+pub fn borrowing_sub_mut(value: &mut usize, rhs: usize, carry: &mut bool) {
+    let (new_value, new_carry) = value.borrowing_sub(rhs, *carry);
     *value = new_value;
-    new_carry
-}
-
-// Copied from an open pr on rust
-#[must_use]
-#[inline]
-pub fn carrying_sub(value: usize, rhs: usize, carry: bool) -> (usize, bool) {
-    let (a, b) = value.overflowing_sub(rhs);
-    let (c, d) = a.overflowing_sub(carry as usize);
-    (c, b | d)
+    *carry = new_carry;
 }
 
 #[cfg(test)]
 mod test {
     use smallvec::{smallvec, SmallVec};
 
-    use crate::integer::big::ops::building_blocks::{add_2, carrying_add_mut, is_well_formed, sub_n, to_twos_complement, widening_mul};
+    use crate::integer::big::ops::building_blocks::{add_2, is_well_formed, sub_n, to_twos_complement};
 
     #[test]
     fn test_is_well_formed() {
@@ -255,14 +214,6 @@ mod test {
         assert!(!is_well_formed(&x));
     }
 
-    #[test]
-    fn test_mul() {
-        assert_eq!(widening_mul(0, 2), (0, 0));
-        assert_eq!(widening_mul(2, 2), (0, 4));
-        assert_eq!(widening_mul(1 << 32, 1 << 32), (1, 0));
-        assert_eq!(widening_mul(1 << 63, 3), (1, 1 << 63));
-    }
-
     #[test]
     fn test_add_2() {
         assert_eq!(add_2(0, 0, 0, 0), (0, 0));
@@ -325,27 +276,4 @@ mod test {
         let expected: SV = smallvec![4];
         assert_eq!(value, expected);
     }
-
-    #[test]
-    fn test_carrying_add_mut() {
-        let mut value = 1;
-        let carry = carrying_add_mut(&mut value, 1, false);
-        assert_eq!((value, carry), (2, false));
-
-        let mut value = 1;
-        let carry = carrying_add_mut(&mut value, 0, true);
-        assert_eq!((value, carry), (2, false));
-
-        let mut value = 1;
-        let carry = carrying_add_mut(&mut value, usize::MAX, false);
-        assert_eq!((value, carry), (0, true));
-
-        let mut value = 2;
-        let carry = carrying_add_mut(&mut value, usize::MAX, false);
-        assert_eq!((value, carry), (1, true));
-
-        let mut value = 1;
-        let carry = carrying_add_mut(&mut value, usize::MAX, true);
-        assert_eq!((value, carry), (1, true));
-    }
 }
