@@ -6,7 +6,7 @@ use std::ptr;
 use smallvec::SmallVec;
 
 use crate::integer::big::BITS_PER_WORD;
-use crate::integer::big::ops::building_blocks::{addmul_1, carrying_add, carrying_add_mut, carrying_sub, carrying_sub_mut, is_well_formed, is_well_formed_non_zero, mul_1, sub_assign_slice, sub_n, to_twos_complement, widening_mul};
+use crate::integer::big::ops::building_blocks::{addmul_1, borrowing_sub_mut, carrying_add_mut, is_well_formed, is_well_formed_non_zero, mul_1, sub_assign_slice, sub_n, to_twos_complement};
 use crate::integer::big::properties::cmp;
 use crate::rational::big::properties::cmp_single;
 
@@ -170,7 +170,7 @@ pub fn add_assign<const S: usize>(values: &mut SmallVec<[usize; S]>, rhs: &[usiz
 
     let mut carry = false;
     while i < values.len() && i < rhs.len() {
-        carry = carrying_add_mut(&mut values[i], rhs[i], carry);
+        carrying_add_mut(&mut values[i], rhs[i], &mut carry);
         i += 1;
     }
 
@@ -198,10 +198,11 @@ pub fn add_assign_single_non_zero<const S: usize>(
     values: &mut SmallVec<[usize; S]>,
     rhs: usize,
 ) {
-    let mut carry = carrying_add_mut(&mut values[0], rhs, false);
+    let mut carry = false;
+    carrying_add_mut(&mut values[0], rhs, &mut carry);
     let mut i = 1;
     while carry && i < values.len() {
-        carry = carrying_add_mut(&mut values[i], 0, true);
+        carrying_add_mut(&mut values[i], 0, &mut carry);
         i += 1;
     }
     if carry {
@@ -215,18 +216,18 @@ pub(crate) fn mul_assign_single_non_zero<const S: usize>(
 ) {
     debug_assert!(!values.is_empty());
     
-    let (mut previous_high, low) = widening_mul(values[0], rhs);
+    let (low, mut previous_high) = values[0].widening_mul(rhs);
     values[0] = low;
     let mut carry = false;
     for i in 1..values.len() {
-        let (high, low) = widening_mul(values[i], rhs);
-        let (value_new, carry_new) = carrying_add(previous_high, low, carry);
+        let (low, high) = values[i].widening_mul(rhs);
+        let (value_new, carry_new) = previous_high.carrying_add(low, carry);
         values[i] = value_new;
         carry = carry_new;
         previous_high = high;
     }
 
-    let (value_new, carry) = carrying_add(previous_high, 0, carry);
+    let (value_new, carry) = previous_high.carrying_add(0, carry);
     if value_new > 0 {
         values.push(value_new);
         if carry {
@@ -288,7 +289,7 @@ pub unsafe fn sub<const S: usize>(
 
     while carry {
         debug_assert!(values.len() > rhs.len());
-        let (value, new_carry) = carrying_sub(values[result.len()], 0, carry);
+        let (value, new_carry) = values[result.len()].borrowing_sub(0, carry);
         carry = new_carry;
         result.push(value);
     }
@@ -323,7 +324,7 @@ pub unsafe fn sub_assign_result_positive<const S: usize>(
     let mut index = 0;
     while carry {
         debug_assert!(values.len() > rhs.len());
-        carry = carrying_sub_mut(&mut values[rhs.len() + index], 0, true);
+        borrowing_sub_mut(&mut values[rhs.len() + index], 0, &mut carry);
         index += 1;
     }
 
@@ -341,14 +342,14 @@ pub fn sub_assign_single_result_positive<const S: usize>(
     debug_assert!(is_well_formed_non_zero(values));
     debug_assert_eq!(cmp_single(values, rhs), Ordering::Greater);
 
-    let mut carry = carrying_sub_mut(&mut values[0], rhs, false);
-
+    let mut carry = false;
+    borrowing_sub_mut(&mut values[0], rhs, &mut carry);
     debug_assert!(is_well_formed_non_zero(values));
 
     let mut index = 0;
     while carry {
         debug_assert!(values.len() > 1);
-        carry = carrying_sub_mut(&mut values[1 + index], 0, carry);
+        borrowing_sub_mut(&mut values[1 + index], 0, &mut carry);
         index += 1;
     }
 
@@ -370,14 +371,14 @@ pub(crate) fn subtracting_cmp<const S: usize>(left: &mut SmallVec<[usize; S]>, r
             let mut i = 0;
             while i < left.len() {
                 // TODO(PERFORMANCE): Is assembler faster?
-                let (new_value, new_carry) = carrying_sub(right[i], left[i], carry);
+                let (new_value, new_carry) = right[i].borrowing_sub(left[i], carry);
                 left[i] = new_value;
                 carry = new_carry;
                 i += 1;
             }
 
             while carry {
-                let (new_value, new_carry) = carrying_sub(right[i], 0, true);
+                let (new_value, new_carry) = right[i].borrowing_sub(0, true);
                 left.push(new_value);
                 carry = new_carry;
                 i += 1;
@@ -395,7 +396,7 @@ pub(crate) fn subtracting_cmp<const S: usize>(left: &mut SmallVec<[usize; S]>, r
             let mut carry = false;
             for i in 0..left.len() {
                 // TODO(PERFORMANCE): Is assembler faster?
-                carry = carrying_sub_mut(&mut left[i], right[i], carry);
+                borrowing_sub_mut(&mut left[i], right[i], &mut carry);
             }
 
             if carry {
@@ -425,7 +426,7 @@ pub(crate) fn subtracting_cmp<const S: usize>(left: &mut SmallVec<[usize; S]>, r
             let mut carry = unsafe { sub_assign_slice(&mut left[..right.len()], right) };
             let mut i = 0;
             while carry && i + right.len() < left.len() {
-                carry = carrying_sub_mut(&mut left[i + right.len()], 0, true);
+                borrowing_sub_mut(&mut left[i + right.len()], 0, &mut carry);
                 i += 1;
             }
             debug_assert!(!carry);
@@ -446,11 +447,12 @@ pub(crate) fn subtracting_cmp_ne_single<const S: usize>(left: &mut SmallVec<[usi
 
     if left.len() > 1 {
         // result won't be negative
-        let mut carry = carrying_sub_mut(&mut left[0], right, false);
+        let mut carry = false;
+        borrowing_sub_mut(&mut left[0], right, &mut carry);
 
         let mut i = 1;
         while carry {
-            carry = carrying_sub_mut(&mut left[i], 0, true);
+            borrowing_sub_mut(&mut left[i], 0, &mut carry);
             i += 1;
         }
 
