@@ -3,6 +3,7 @@ use std::ops::Neg;
 
 use crate::integer::big::ops::div::div as div_by_odd_or_even;
 use crate::integer::big::ops::normalize::gcd;
+use crate::Negateable;
 use crate::rational::big::Big;
 
 mod add_sub;
@@ -33,7 +34,7 @@ impl<const S: usize> Neg for Big<S> {
     #[must_use]
     #[inline]
     fn neg(mut self) -> Self::Output {
-        self.sign = !self.sign;
+        self.sign.negate();
         self
     }
 }
