@@ -4,9 +4,10 @@ use std::fmt::Display;
 use std::ops::Neg;
 
 use crate::integer::big::ops::normalize::gcd_scalar;
-use crate::non_zero::{NonZero, NonZeroSign, NonZeroSigned};
+use crate::Negateable;
+use crate::non_zero::NonZeroSign;
 use crate::rational::Ratio;
-use crate::sign::{Sign, Signed};
+use crate::sign::Sign;
 
 mod io;
 pub(crate) mod ops;
@@ -16,29 +17,13 @@ macro_rules! rational {
         /// A signed ratio between two small integers.
         pub type $name = Ratio<Sign, $uty, $uty>;
 
-        impl Signed for $name {
-            fn signum(&self) -> Sign {
-                self.sign
-            }
-        }
-
-        impl NonZeroSigned for $name {
-            #[must_use]
-            #[inline]
-            fn signum(&self) -> NonZeroSign {
-                debug_assert!(self.is_not_zero());
-
-                self.sign.into()
-            }
-        }
-
         impl Neg for $name {
             type Output = Self;
 
             #[must_use]
             #[inline]
             fn neg(mut self) -> Self::Output {
-                self.sign = !self.sign;
+                Negateable::negate(&mut self.sign);
                 self
             }
         }
@@ -98,6 +83,7 @@ rational!(Rational8, i8, u8);
 rational!(Rational16, i16, u16);
 rational!(Rational32, i32, u32);
 rational!(Rational64, i64, u64);
+rational!(RationalUsize, isize, usize);
 rational!(Rational128, i128, u128);
 
 macro_rules! rational_non_zero {
@@ -120,6 +106,7 @@ rational_non_zero!(NonZeroRational16, i16, u16);
 rational_non_zero!(NonZeroRational32, i32, u32);
 rational_non_zero!(NonZeroRational64, i64, u64);
 rational_non_zero!(NonZeroRational128, i128, u128);
+rational_non_zero!(NonZeroRationalUsize, isize, usize);
 
 #[cfg(test)]
 mod test {
@@ -169,13 +156,13 @@ mod test {
         assert!(!Rational8::zero().is_not_zero());
         assert_eq!(Rational16::zero().is_zero(), !Rational16::zero().is_not_zero());
 
-        assert_eq!(R8!(1).signum(), NonZeroSign::Positive);
+        assert_eq!(R8!(1).non_zero_signum(), NonZeroSign::Positive);
     }
 
     #[test]
     #[should_panic]
     fn test_sign_panic() {
-        R8!(0).signum();
+        R8!(0).non_zero_signum();
     }
 
     #[test]
